==> nextcloud-27.1.2.tgz: nextcloud/apps/oauth2/l10n/hr.js <==
OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "Vaš klijent nije ovlašten za povezivanje. Obavijestite administratora svog klijenta.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "Vaš URL za preusmjeravanje mora biti cjelovit URL, primjerice: https://yourdomain.com/path",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Omogućuje autentifikaciju kompatibilnu s OAuth2 iz drugih web aplikacija.",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "Aplikacija OAuth2 omogućuje administratorima da konfiguriraju ugrađeni tijek autentifikacije kako bi također omogućili autentifikaciju kompatibilnu s OAuth2 iz drugih web aplikacija.",
    "OAuth 2.0 clients" : "OAuth 2.0 klijenti",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "OAuth 2.0 omogućuje vanjskim servisima da zahtijevaju pristup {instanceName}.",
    "Add client" : "Dodaj klijenta",
    "Name" : "Naziv",
    "Redirection URI" : "URL za preusmjeravanje",
    "Add" : "Dodaj",
    "Client Identifier" : "Identifikator klijenta",
    "Secret" : "Tajno",
    "Show client secret" : "Prikaži tajni ključ klijenta",
    "Delete" : "Izbriši"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");

==> nextcloud-27.1.4.tgz: nextcloud/apps/oauth2/l10n/hr.js <==
OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "Vaš klijent nije ovlašten za povezivanje. Obavijestite administratora svog klijenta.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "Vaš URL za preusmjeravanje mora biti cjelovit URL, primjerice: https://yourdomain.com/path",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Omogućuje autentifikaciju kompatibilnu s OAuth2 iz drugih web aplikacija.",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "Aplikacija OAuth2 omogućuje administratorima da konfiguriraju ugrađeni tijek autentifikacije kako bi također omogućili autentifikaciju kompatibilnu s OAuth2 iz drugih web aplikacija.",
    "OAuth 2.0 clients" : "OAuth 2.0 klijenti",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "OAuth 2.0 omogućuje vanjskim servisima da zahtijevaju pristup {instanceName}.",
    "Name" : "Naziv",
    "Redirection URI" : "URL za preusmjeravanje",
    "Client Identifier" : "Identifikator klijenta",
    "Secret key" : "Tajni ključ",
    "Add client" : "Dodaj klijenta",
    "Add" : "Dodaj",
    "Show client secret" : "Prikaži tajni ključ klijenta",
    "Delete" : "Izbriši",
    "Secret" : "Tajno"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
